Installing a development environment - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Installing a development environment

These instructions are focused on setting up a Betty development environment.

## Requirements

- Linux, macOS, or Windows

- Python 3.11+

- Node.js 20+ (required by some extensions)

- ShellCheck

- Xvfb

- Bash

- The Playwright requirements (required to run Playwright tests)

## Instructions

1. `git clone https://github.com/bartfeenstra/betty.git`

2. `cd betty`

3. `./bin/build-dev`